@@ -1,8 +1,9 @@
 from typing import List, Optional
 
-from nwon_baseline.typings import PydanticBaseDjango
 from pydantic import Field
 
+from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
+
 
 class NWONDjangoSettings(PydanticBaseDjango):
     """
