@@ -1,4 +1,4 @@
-from nwon_baseline.typings import PydanticBaseDjango
+from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
 
 
 class TestFixture(PydanticBaseDjango):
